#!/bin/sh
#
# Script to be run from crontab on buildlogs host.
# Moves buildlogs around.
#
# Expected directory structure:
#
# root/$(dist)/$(arch)/
#   .new/
#   OK/
#   FAIL/
#   prevOK/
#
# Note that we look for root/*/*/.new/*.info, so don't place any additional
# directories there.

root="/home/services/ftpd/buildlogs"

if test -f /etc/buildlogs-mover.conf ; then
  . /etc/buildlogs-mover.conf
fi

for n in $root/*/*/.new ; do
  if test -d $n ; then
    echo "$n doesn't exists or ain't directory"
    exit 1
  fi
  break # don't check all
done

handle_info () {
  info="$1"
  info_val="$(cat "$info" 2>/dev/null)"
  if echo "$info_val" | grep -q '^END$' ; then
    rm "$info" 2>/dev/null || return
    status=$(echo "$info_val" | grep '^Status:' | sed -e 's/.*: *//')
    case $status in
      OK ) s=OK ;;
      FAIL* ) s=FAIL ;;
      * )
        # this script is run from cron, so this should go through mail 
	# to admin
        echo "bad buildlog status: $status in $info:" 1>&2
	echo "#v+" 1>&2
	echo "$info_val" 1>&2
	echo "#v-" 1>&2
	return
        ;;
    esac
    archdir="$(dirname "$(dirname "$info")")"
    file=$(basename "$info" .info)
    if test -f "$archdir/OK/$file" ; then
      mv -f "$archdir/OK/$file" "$archdir/prevOK/$file"
    fi
    rm -f "$archdir/"{OK,FAIL}"/$file"
    mv -f "$archdir/.new/$file" "$archdir/$s/$file"
  fi
}

for info in $root/*/*/.new/*.info ; do
  if test -f "$info" ; then
    handle_info "$info"
  fi
done
